## Citations Formats:

- For scientific literature in the form of books or articles in peer-reviewed journals:
    APA7 guidelines
- For Websites or resources available by following a link to an html, pdf, or other formatted style output:
    Author, Organization, Title, url, "Accesssed" date accessed [Mon. dd, yyyy]
- For YouTube:
    Poster username, Channel, date posted [Mon. dd, yyyy] "YouTube", , url, "Accessed" date accessed [Mon. dd, yyyy]
- For software packages:
    Platform username, package name, version, link
- For source code:
  - On GitHub:
    username/repo, link, access date [Mon. dd, yyyy]
